Predictive Modelling Metadata Interchange Format
================================================

Python support for dataset metadata for predictive modelling and data analysis.

The `pmmif` package provides two levels of support.

.pmm Metadata Files
--------------------

Classes for reading and writing extended metadata to .pmm JSON files.


Pandas DataFrame Support
------------------------

Classes for associating Pandas DataFrames with additional `type` and
`tags` annotation metadata, including support for persisting additional
metadata alongside `feather` datafiles.


Documentation
=============

http://pmmif.readthedocs.io

